@@ -31,7 +31,7 @@ import pickle
 import time
 import sys
 from httplib import HTTPSConnection
-from jose import jwt
+import jwt
 
 from Requester import Requester, json
 import AuthenticatedUser
